==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/cabin1/dialogs_cs.lua <==

dialogId("k1-pap-3xkruty", "font_parrot", "Crrruel, crrruel, crrruel Captain Silverrrr...")
dialogStr("Krrrutý, krrrutý, krrrutý kapitán Silverrrr...")


dialogId("k1-pap-karamba", "font_parrot", "Ay... caramba!!!")
dialogStr("Oj... karamba!!!")


dialogId("k1-pap-kruty", "font_parrot", "Crrruel Captain Silverrrr...")
dialogStr("Krrrutý kapitán Silverrrr...")


dialogId("k1-pap-drahokamy", "font_parrot", "Trrreasurre, you foools...")
dialogStr("Drrrahokamy, trrroubové...")


dialogId("k1-pap-kruci", "font_parrot", "Good grrrief!")
dialogStr("Krrruci!")


dialogId("k1-pap-drahousek", "font_parrot", "That`s rrrrrridiculous! Polly is his masterrr`s darrrling.")
dialogStr("To si vyprrrošuju, Lóra je pánův drrrahoušek.")


dialogId("k1-pap-nestrkej", "font_parrot", "Don`t ppppush me!")
dialogStr("Nestrrrkej do mě!")


dialogId("k1-pap-noproto", "font_parrot", "That`s betterrr!")
dialogStr("No prroto!")


dialogId("k1-pap-prcice", "font_parrot", "And it`s currrtains forrr you!")
dialogStr("A jste v prrrčicích!")


dialogId("k1-pap-prekazet", "font_parrot", "I`m going to be in yourrr way herrre.")
dialogStr("Tady vám budu strrrašně překážet.")


dialogId("k1-pap-problem", "font_parrot", "Trrricky prrroblem, isn`t it?")
dialogStr("Zatrrraceny prrroblém, není-liž prrravda?")


dialogId("k1-pap-sakris", "font_parrot", "Dang it!")
dialogStr("Sákrrriš")


dialogId("k1-pap-sestlustej", "font_parrot", "You`rrre too fat, you can`t make it thrrrrough.")
dialogStr("Jseš tlustej, neprrrojedeš...")


dialogId("k1-pap-sucharek", "font_parrot", "Polly wants a crrracker!")
dialogStr("Lórrra chce suchárrrek!")


dialogId("k1-pap-trhnisi", "font_parrot", "Beat it, sirrr...")
dialogStr("Trrrhni si...")


dialogId("k1-pap-vodprejskni", "font_parrot", "Leave me alone and get lost!")
dialogStr("Nevotrrravuj a vodprrrejskni!")


dialogId("k1-m-copak", "font_small", "What could be inside?")
dialogStr("Copak je asi uvnitř?")


dialogId("k1-v-kdovi", "font_big", "Who knows...")
dialogStr("Kdo ví...")


dialogId("k1-m-myslis", "font_small", "Could this be the legendary Silver`s treasure?")
dialogStr("Myslíš, že by to mohl být legendarní Silverův poklad?")


dialogId("k1-v-bedna", "font_big", "In such a small chest? The boss surely wouldn`t contact us for such a little case.")
dialogStr("V tak malé truhle? Kvůli jedné takové bedničce by nás šéf určitě nekontaktoval.")


dialogId("k1-m-fuj", "font_small", "Yuck!")
dialogStr("Fuj!")


dialogId("k1-m-diky", "font_small", "Thanks.")
dialogStr("Díky.")


dialogId("k1-v-radose", "font_big", "No problem.")
dialogStr("Rádo se stalo.")


dialogId("k1-m-codelas", "font_small", "What are you doing?!")
dialogStr("Co to děláš?!")


dialogId("k1-v-promin", "font_big", "I`m sorry. I`ll be more careful next time.")
dialogStr("Promiň, už si dám pozor...")


dialogId("k1-v-opatrne", "font_big", "Be careful! Don`t hurt it!")
dialogStr("Opatrně, ať jí neublížíš.")


dialogId("k1-m-tospisona", "font_small", "It`s more the other way around!")
dialogStr("To spíš ona mně!")


dialogId("k1-m-chobotnice", "font_small", "That`s some octopus! I wonder who`s her owner?")
dialogStr("To je ale chobotnice! Komupak asi patří?")


dialogId("k1-v-patrila", "font_big", "Maybe it belonged to the person who lived in this cabin.")
dialogStr("Možná patřila obyvateli této kajuty.")


dialogId("k1-m-podivin", "font_small", "Whoever lived here sure was weird.")
dialogStr("Ten, kdo tu bydlel, byl asi podivín.")


dialogId("k1-v-proc", "font_big", "Why?")
dialogStr("Proč?")


dialogId("k1-m-lebku", "font_small", "Look, he had a human skull here!")
dialogStr("Podívej, měl tu lidskou lebku!")


dialogId("k1-v-jejeho", "font_big", "Well, maybe it`s his own skull.")
dialogStr("Víš, možná je to ta jeho.")


dialogId("k1-m-mysli", "font_small", "You think so?")
dialogStr("Myslíš?")


dialogId("k1-v-citis", "font_big", "Can you sense the atmosphere of rot and decay? The sunken wreck, the parrot`s skeleton, the human skull, and the broken cradle...")
dialogStr("Cítíš tu tíživou atmosféru? Potopený vrak, kostra papouška, lidská lebka, převrácená kolébka...")


dialogId("k1-m-kolebku", "font_small", "Where do you see the cradle?")
dialogStr("Kde vidíš tu kolébku?")


dialogId("k1-v-cit", "font_big", "Oh, you don`t have any feeling for poetry at all...")
dialogStr("Ach jo, ty nemáš vůbec cit pro poezii...")

==> fillets-ng-data_1.0.1.orig.tar.gz: fillets-ng-data-1.0.1/script/cabin1/dialogs_cs.lua <==

dialogId("k1-pap-3xkruty", "font_parrot", "Crrruel, crrruel, crrruel Captain Silverrrr...")
dialogStr("Krrrutý, krrrutý, krrrutý kapitán Silverrrr...")


dialogId("k1-pap-karamba", "font_parrot", "Ay... caramba!!!")
dialogStr("Oj... karamba!!!")


dialogId("k1-pap-kruty", "font_parrot", "Crrruel Captain Silverrrr...")
dialogStr("Krrrutý kapitán Silverrrr...")


dialogId("k1-pap-drahokamy", "font_parrot", "Trrreasurre, you foools...")
dialogStr("Drrrahokamy, trrroubové...")


dialogId("k1-pap-kruci", "font_parrot", "Good grrrief!")
dialogStr("Krrruci!")


dialogId("k1-pap-drahousek", "font_parrot", "That’s rrrrrridiculous! Polly is his masterrr’s darrrling.")
dialogStr("To si vyprrrošuju, Lóra je pánův drrrahoušek.")


dialogId("k1-pap-nestrkej", "font_parrot", "Don’t ppppush me!")
dialogStr("Nestrrrkej do mě!")


dialogId("k1-pap-noproto", "font_parrot", "That’s betterrr!")
dialogStr("No prroto!")


dialogId("k1-pap-prcice", "font_parrot", "And it’s currrtains forrr you!")
dialogStr("A jste v prrrčicích!")


dialogId("k1-pap-prekazet", "font_parrot", "I’m going to be in yourrr way herrre.")
dialogStr("Tady vám budu strrrašně překážet.")


dialogId("k1-pap-problem", "font_parrot", "Trrricky prrroblem, isn’t it?")
dialogStr("Zatrrraceny prrroblém, není-liž prrravda?")


dialogId("k1-pap-sakris", "font_parrot", "Dang it!")
dialogStr("Sákrrriš")


dialogId("k1-pap-sestlustej", "font_parrot", "You’rrre too fat, you can’t make it thrrrrough.")
dialogStr("Jseš tlustej, neprrrojedeš...")


dialogId("k1-pap-sucharek", "font_parrot", "Polly wants a crrracker!")
dialogStr("Lórrra chce suchárrrek!")


dialogId("k1-pap-trhnisi", "font_parrot", "Beat it, sirrr...")
dialogStr("Trrrhni si...")


dialogId("k1-pap-vodprejskni", "font_parrot", "Leave me alone and get lost!")
dialogStr("Nevotrrravuj a vodprrrejskni!")


dialogId("k1-m-copak", "font_small", "What could be inside?")
dialogStr("Copak je asi uvnitř?")


dialogId("k1-v-kdovi", "font_big", "Who knows...")
dialogStr("Kdo ví...")


dialogId("k1-m-myslis", "font_small", "Could this be the legendary Silver’s treasure?")
dialogStr("Myslíš, že by to mohl být legendarní Silverův poklad?")


dialogId("k1-v-bedna", "font_big", "In such a small chest? The boss surely wouldn’t contact us for such a little case.")
dialogStr("V tak malé truhle? Kvůli jedné takové bedničce by nás šéf určitě nekontaktoval.")


dialogId("k1-m-fuj", "font_small", "Yuck!")
dialogStr("Fuj!")


dialogId("k1-m-diky", "font_small", "Thanks.")
dialogStr("Díky.")


dialogId("k1-v-radose", "font_big", "No problem.")
dialogStr("Rádo se stalo.")


dialogId("k1-m-codelas", "font_small", "What are you doing?!")
dialogStr("Co to děláš?!")


dialogId("k1-v-promin", "font_big", "I’m sorry. I’ll be more careful next time.")
dialogStr("Promiň, už si dám pozor...")


dialogId("k1-v-opatrne", "font_big", "Be careful! Don’t hurt it!")
dialogStr("Opatrně, ať jí neublížíš.")


dialogId("k1-m-tospisona", "font_small", "It’s more the other way around!")
dialogStr("To spíš ona mně!")


dialogId("k1-m-chobotnice", "font_small", "That’s some octopus! I wonder who’s her owner?")
dialogStr("To je ale chobotnice! Komupak asi patří?")


dialogId("k1-v-patrila", "font_big", "Maybe it belonged to the person who lived in this cabin.")
dialogStr("Možná patřila obyvateli této kajuty.")


dialogId("k1-m-podivin", "font_small", "Whoever lived here sure was weird.")
dialogStr("Ten, kdo tu bydlel, byl asi podivín.")


dialogId("k1-v-proc", "font_big", "Why?")
dialogStr("Proč?")


dialogId("k1-m-lebku", "font_small", "Look, he had a human skull here!")
dialogStr("Podívej, měl tu lidskou lebku!")


dialogId("k1-v-jejeho", "font_big", "Well, maybe it’s his own skull.")
dialogStr("Víš, možná je to ta jeho.")


dialogId("k1-m-mysli", "font_small", "You think so?")
dialogStr("Myslíš?")


dialogId("k1-v-citis", "font_big", "Can you sense the atmosphere of rot and decay? The sunken wreck, the parrot’s skeleton, the human skull, and the broken cradle...")
dialogStr("Cítíš tu tíživou atmosféru? Potopený vrak, kostra papouška, lidská lebka, převrácená kolébka...")


dialogId("k1-m-kolebku", "font_small", "Where do you see the cradle?")
dialogStr("Kde vidíš tu kolébku?")


dialogId("k1-v-cit", "font_big", "Oh, you don’t have any feeling for poetry at all...")
dialogStr("Ach jo, ty nemáš vůbec cit pro poezii...")
